@@ -1,7 +1,6 @@
 extern crate proc_macro;
 
 mod attribute;
-mod target;
 mod uniform;
 
 use ::syn::{GenericParam, Generics, TypeParamBound};
@@ -15,12 +14,7 @@ fn add_trait_bounds(mut generics: Generics, params: Vec<TypeParamBound>) -> Gene
     }
     generics
 }
-
 use ::proc_macro::TokenStream;
-#[proc_macro]
-pub fn gl_target(input: TokenStream) -> TokenStream {
-    target::gl_target(input)
-}
 
 ///Create a ToUniform implementaion from the given struct.
 #[proc_macro_derive(ToUniform)]
